@@ -26,7 +26,7 @@ function hoursTickFormatter(format, val) {
 
 
 function dateTickFormatter(format, val) {
-    return $.jsDate.strftime(val, format);
+    return $.jsDate.strftime(val);
 };
 
 
